figaro.exceptions
=================

.. automodule:: figaro.exceptions

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      except_hook
   
   

   
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      FIGAROException
   
   



